@@ -3,9 +3,7 @@
 
 from trytond.pool import Pool
 
-from . import party
-from . import company
-from . import res
+from . import company, party, res
 
 __all__ = ['register']
 
